@@ -2,6 +2,8 @@ from .numcalc import (
     manage_numcalc,
     remove_outputs,
     read_ram_estimates,
+    calc_and_read_ram,
+    create_hpc_files,
     )
 
 
@@ -9,4 +11,6 @@ __all__ = [
     'manage_numcalc',
     'remove_outputs',
     'read_ram_estimates',
+    'calc_and_read_ram',
+    'create_hpc_files',
     ]
